# School Algorithms
###### School algorithm module for Python
**school_algorithms** is a **Python** module for secondary school
maths and physics equations.

It aims to provide a simple way for secondary school students
to learn and calculate equations that they often use.

Functions include:
- A function that calculates power from energy and time
- A function that calculates energy from power and time
- A function that calculates time from power and energy
- A function that uses Pythagorean theorem to calculate the hypotenuse of a right-angled triangle
- A function that uses Pythagorean theorem to calculate a leg of a right-angled triangle
- A function that calculates the  area of a triangle
